@@ -8,15 +8,15 @@ from typing import Tuple
 from egse.decorators import dynamic_interface
 from egse.device import DeviceConnectionState
 from egse.device import DeviceInterface
+from egse.log import logger
 from egse.mixin import DynamicCommandMixin, CommandType
 from egse.mixin import add_lf
 from egse.mixin import dynamic_command
 from egse.proxy import Proxy
 from egse.settings import Settings
-from egse.tempcontrol.keithley.daq6510_dev import DAQ6510EthernetInterface
+from egse.tempcontrol.keithley.daq6510_dev import DAQ6510
 from egse.zmq_ser import connect_address
 
-logger = logging.getLogger(__name__)
 
 HERE = Path(__file__).parent
 
@@ -235,7 +235,7 @@ class DAQ6510Controller(DAQ6510Interface, DynamicCommandMixin):
 
         logger.debug(f"Initializing the DAQ6510 Controller with hostname={hostname} on port={port}")
 
-        self.daq = self.transport = DAQ6510EthernetInterface(hostname, port)
+        self.daq = self.transport = DAQ6510(hostname, port)
 
         # We set the default buffer here, this can be changed with the `create_buffer()` method.
 
